@@ -1,4 +1,4 @@
-// Copyright 2016 Daniel Parker
+// Copyright 2013-2024 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -23,7 +23,7 @@
 #include <system_error>
 #include <limits>
 #include <jsoncons/config/compiler_support.hpp>
-#include <jsoncons/more_type_traits.hpp>
+#include <jsoncons/extension_traits.hpp>
 
 namespace jsoncons { namespace unicode_traits {
 
@@ -57,7 +57,7 @@ namespace jsoncons { namespace unicode_traits {
     };
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value,detect_encoding_result<CharT>>::type
+    typename std::enable_if<extension_traits::is_char8<CharT>::value,detect_encoding_result<CharT>>::type
     detect_encoding_from_bom(const CharT* data, std::size_t length)
     {
         const uint8_t bom_utf8[] = {0xef,0xbb,0xbf}; 
@@ -93,14 +93,14 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char16<CharT>::value || type_traits::is_char32<CharT>::value,detect_encoding_result<CharT>>::type
+    typename std::enable_if<extension_traits::is_char16<CharT>::value || extension_traits::is_char32<CharT>::value,detect_encoding_result<CharT>>::type
     detect_encoding_from_bom(const CharT* data, std::size_t)
     {
         return detect_encoding_result<CharT>{data,encoding_kind::undetected};
     }
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value,detect_encoding_result<CharT>>::type
+    typename std::enable_if<extension_traits::is_char8<CharT>::value,detect_encoding_result<CharT>>::type
     detect_json_encoding(const CharT* data, std::size_t length)
     {
         detect_encoding_result<CharT> r = detect_encoding_from_bom(data,length);
@@ -135,7 +135,7 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char16<CharT>::value || type_traits::is_char32<CharT>::value,detect_encoding_result<CharT>>::type
+    typename std::enable_if<extension_traits::is_char16<CharT>::value || extension_traits::is_char32<CharT>::value,detect_encoding_result<CharT>>::type
     detect_json_encoding(const CharT* data, std::size_t)
     {
         return detect_encoding_result<CharT>{data,encoding_kind::undetected};
@@ -294,7 +294,7 @@ namespace jsoncons { namespace unicode_traits {
     // utf8
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value, conv_errc>::type
+    typename std::enable_if<extension_traits::is_char8<CharT>::value, conv_errc>::type
     is_legal_utf8(const CharT* first, std::size_t length) 
     {
         uint8_t a;
@@ -373,7 +373,7 @@ namespace jsoncons { namespace unicode_traits {
     // to_codepoint
 
     template <class CharT,class CodepointT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value && type_traits::is_char32<CodepointT>::value,
+    typename std::enable_if<extension_traits::is_char8<CharT>::value && extension_traits::is_char32<CodepointT>::value,
                             convert_result<CharT>>::type 
     to_codepoint(const CharT* first, const CharT* last, 
                  CodepointT& ch, 
@@ -455,7 +455,7 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class CodepointT>
-    typename std::enable_if<type_traits::is_char16<CharT>::value && type_traits::is_char32<CodepointT>::value,
+    typename std::enable_if<extension_traits::is_char16<CharT>::value && extension_traits::is_char32<CodepointT>::value,
                             convert_result<CharT>>::type 
     to_codepoint(const CharT* first, const CharT* last, 
                  CodepointT& ch, 
@@ -510,7 +510,7 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class CodepointT>
-    typename std::enable_if<type_traits::is_char32<CharT>::value && type_traits::is_char32<CodepointT>::value,
+    typename std::enable_if<extension_traits::is_char32<CharT>::value && extension_traits::is_char32<CodepointT>::value,
                             convert_result<CharT>>::type 
     to_codepoint(const CharT* first, const CharT* last, 
                  CodepointT& ch, 
@@ -546,9 +546,9 @@ namespace jsoncons { namespace unicode_traits {
     // convert
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char8<CharT>::value
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char8<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char8<CharT>::value
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char8<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, Container& target, conv_flags flags=conv_flags::strict) 
     {
@@ -582,9 +582,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char8<CharT>::value
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char16<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char8<CharT>::value
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char16<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -659,9 +659,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char8<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char32<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char8<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char32<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -743,9 +743,9 @@ namespace jsoncons { namespace unicode_traits {
     // utf16
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char16<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char8<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char16<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char8<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
                      Container& target, 
@@ -843,9 +843,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char16<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char16<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char16<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char16<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -900,9 +900,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char16<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char32<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char16<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char32<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -953,9 +953,9 @@ namespace jsoncons { namespace unicode_traits {
     // utf32
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char32<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char8<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char32<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char8<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -1039,9 +1039,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char32<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char16<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char32<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char16<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -1084,9 +1084,9 @@ namespace jsoncons { namespace unicode_traits {
     }
 
     template <class CharT,class Container>
-    typename std::enable_if<type_traits::is_char32<CharT>::value                            
-                            && type_traits::is_back_insertable<Container>::value
-                            && type_traits::is_char32<typename Container::value_type>::value,
+    typename std::enable_if<extension_traits::is_char32<CharT>::value                            
+                            && extension_traits::is_back_insertable<Container>::value
+                            && extension_traits::is_char32<typename Container::value_type>::value,
                             convert_result<CharT>>::type 
     convert(const CharT* data, std::size_t length, 
             Container& target, 
@@ -1124,7 +1124,7 @@ namespace jsoncons { namespace unicode_traits {
     // validate
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value,
+    typename std::enable_if<extension_traits::is_char8<CharT>::value,
                             convert_result<CharT>>::type 
     validate(const CharT* data, std::size_t length) noexcept
     {
@@ -1149,7 +1149,7 @@ namespace jsoncons { namespace unicode_traits {
     // utf16
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char16<CharT>::value,
+    typename std::enable_if<extension_traits::is_char16<CharT>::value,
                             convert_result<CharT>>::type 
     validate(const CharT* data, std::size_t length)  noexcept
     {
@@ -1195,7 +1195,7 @@ namespace jsoncons { namespace unicode_traits {
     // utf32
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char32<CharT>::value,
+    typename std::enable_if<extension_traits::is_char32<CharT>::value,
                             convert_result<CharT>>::type 
     validate(const CharT* data, std::size_t length) noexcept
     {
@@ -1299,7 +1299,7 @@ namespace jsoncons { namespace unicode_traits {
     // count_codepoints
 
     template <class CharT>
-    typename std::enable_if<type_traits::is_char8<CharT>::value || type_traits::is_char16<CharT>::value || type_traits::is_char32<CharT>::value, std::size_t>::type 
+    typename std::enable_if<extension_traits::is_char8<CharT>::value || extension_traits::is_char16<CharT>::value || extension_traits::is_char32<CharT>::value, std::size_t>::type 
     count_codepoints(const CharT* data, std::size_t length, 
                      conv_flags flags = conv_flags::strict) noexcept
     {
